@@ -1,4 +1,7 @@
 from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port
+from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
+from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
+
 
 def filed(key,inquire=[]):
     """
@@ -42,7 +45,26 @@ def filed(key,inquire=[]):
         'DefaultLogGroupID':id.date().getDefaultLogGroupID,
         'asLogWareID':id.date().getAsLogWareID,
         'httpUrl':kai.machine(inquire).getAlertHttpUrl,
-        'lastFiveYearTime':timestamp.date().getLastFiveYearTime
+        'lastFiveYearTime':timestamp.date().getLastFiveYearTime,
+        'alertmergeID': ParaDateFiledServer().getUUid,
+        'fromID': ParaDateFiledServer().getFromTime,
+        'ToID': ParaDateFiledServer().getToTime,
+        'StartDateID': ParaDateFiledServer().getStartDate,
+        'EndDateID': ParaDateFiledServer().getEndDate,
+        'TimeRangeID': ParaDateFiledServer().getTimeRangeId,
+        'RangeUnitID': ParaDateFiledServer().getRangeUnitId,
+        'TimeLabelID': ParaDateFiledServer().getTimeLabelId,
+        'serviceID': ParaDateAnyRobotServer(key).getServiceId,
+        'KpiID': ParaDateAnyRobotServer(key).getKpiId,
+        'kpiNameID': ParaDateFiledServer().getkpiNameID,
+        'kpiNameId': ParaDateFiledServer().kpiNameId,
+        'SavedSearchID': ParaDateAnyRobotServer(key).getSavedSearchId,
+        'SavedSearchNameID': ParaDateAnyRobotServer(key).getSavedSearchNameId,
+        'SavedSearchLogGroupID': ParaDateAnyRobotServer(key).getSavedSearchLogGroupId,
+        'SavedSearchLogLibraryID': ParaDateAnyRobotServer(key).getSavedSearchLogLibraryId,
+        'AlertRuleNamesID': ParaDateAnyRobotServer(key).getAlertRuleNamesId,
+        'AlertScenarioID': ParaDateAnyRobotServer(key).getAlertScenarioId,
+        'DeleteAlertRuleNamesID': ParaDateAnyRobotServer(key).getDeleteAlertRuleNamesId
     }
 
     switcher = SERVICE_KPI_
